==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-category-y-axis.js <==
import * as tslib_1 from "tslib";
import { IgrCategoryAxisBase } from "./igr-category-axis-base";
import { CategoryYAxis } from "./CategoryYAxis";
import { toPoint, fromRect } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent category Y axis.
*/
var IgrCategoryYAxis = /** @class */ (function (_super) {
    tslib_1.__extends(IgrCategoryYAxis, _super);
    function IgrCategoryYAxis(props) {
        return _super.call(this, props) || this;
    }
    IgrCategoryYAxis.prototype.createImplementation = function () {
        return new CategoryYAxis();
    };
    Object.defineProperty(IgrCategoryYAxis.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryYAxis.prototype, "isVertical", {
        /**
         * Gets if the current axis is a vertical axis.
        */
        get: function () {
            return this.i.ce;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryYAxis.prototype, "interval", {
        /**
         * Gets or sets the frequency of displayed labels.
         * The set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
        */
        get: function () {
            return this.i.kw;
        },
        set: function (v) {
            this.i.kw = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryYAxis.prototype, "actualInterval", {
        /**
         * Gets the effective value for the current Interval.
        */
        get: function () {
            return this.i.ks;
        },
        set: function (v) {
            this.i.ks = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryYAxis.prototype, "minorInterval", {
        /**
         * Gets or sets the frequency of displayed minor lines.
         * The set value is a factor that determines how the minor lines will be displayed.
        */
        get: function () {
            return this.i.kx;
        },
        set: function (v) {
            this.i.kx = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryYAxis.prototype, "actualMinorInterval", {
        /**
         * Gets the effective value for the current MinorInterval.
        */
        get: function () {
            return this.i.ku;
        },
        set: function (v) {
            this.i.ku = +v;
        },
        enumerable: true,
        configurable: true
    });
    IgrCategoryYAxis.prototype.getCategoryBoundingBox = function (point, useInterpolation, singularWidth) {
        var iv = this.i.kn(toPoint(point), useInterpolation, singularWidth);
        return fromRect(iv);
    };
    IgrCategoryYAxis.prototype.scrollRangeIntoView = function (minimum, maximum) {
        this.i.k7(minimum, maximum);
    };
    /**
     * Scrolls the specified item into view.
    
    * @param item  * Data item to scroll into view
    */
    IgrCategoryYAxis.prototype.scrollIntoView = function (item) {
        this.i.k6(item);
    };
    return IgrCategoryYAxis;
}(IgrCategoryAxisBase));
export { IgrCategoryYAxis };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/igr-category-y-axis.js <==
import * as tslib_1 from "tslib";
import { IgrCategoryAxisBase } from "./igr-category-axis-base";
import { CategoryYAxis } from "./CategoryYAxis";
import { toPoint, fromRect } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents a IgxDataChartComponent category Y axis.
*/
var IgrCategoryYAxis = /** @class */ (function (_super) {
    tslib_1.__extends(IgrCategoryYAxis, _super);
    function IgrCategoryYAxis(props) {
        return _super.call(this, props) || this;
    }
    IgrCategoryYAxis.prototype.createImplementation = function () {
        return new CategoryYAxis();
    };
    Object.defineProperty(IgrCategoryYAxis.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryYAxis.prototype, "isVertical", {
        /**
         * Gets if the current axis is a vertical axis.
        */
        get: function () {
            return this.i.cf;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryYAxis.prototype, "interval", {
        /**
         * Gets or sets the frequency of displayed labels.
         * The set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
        */
        get: function () {
            return this.i.k3;
        },
        set: function (v) {
            this.i.k3 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryYAxis.prototype, "actualInterval", {
        /**
         * Gets the effective value for the current Interval.
        */
        get: function () {
            return this.i.kz;
        },
        set: function (v) {
            this.i.kz = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryYAxis.prototype, "minorInterval", {
        /**
         * Gets or sets the frequency of displayed minor lines.
         * The set value is a factor that determines how the minor lines will be displayed.
        */
        get: function () {
            return this.i.k4;
        },
        set: function (v) {
            this.i.k4 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryYAxis.prototype, "actualMinorInterval", {
        /**
         * Gets the effective value for the current MinorInterval.
        */
        get: function () {
            return this.i.k1;
        },
        set: function (v) {
            this.i.k1 = +v;
        },
        enumerable: true,
        configurable: true
    });
    IgrCategoryYAxis.prototype.getCategoryBoundingBox = function (point, useInterpolation, singularWidth) {
        var iv = this.i.ku(toPoint(point), useInterpolation, singularWidth);
        return fromRect(iv);
    };
    IgrCategoryYAxis.prototype.scrollRangeIntoView = function (minimum, maximum) {
        this.i.le(minimum, maximum);
    };
    /**
     * Scrolls the specified item into view.
    
    * @param item  * Data item to scroll into view
    */
    IgrCategoryYAxis.prototype.scrollIntoView = function (item) {
        this.i.ld(item);
    };
    return IgrCategoryYAxis;
}(IgrCategoryAxisBase));
export { IgrCategoryYAxis };
